==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayListFluent<A extends GatewayListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Gateway item);
  public A setToItems(Integer index,Gateway item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public A addAllToItems(Collection<Gateway> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public A removeAllFromItems(Collection<Gateway> items);
  public A removeMatchingFromItems(Predicate<GatewayBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Gateway> getItems();
  public List<Gateway> buildItems();
  public Gateway buildItem(Integer index);
  public Gateway buildFirstItem();
  public Gateway buildLastItem();
  public Gateway buildMatchingItem(Predicate<GatewayBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GatewayBuilder> predicate);
  public A withItems(List<Gateway> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public Boolean hasItems();
  public GatewayListFluent.ItemsNested<A> addNewItem();
  public GatewayListFluent.ItemsNested<A> addNewItemLike(Gateway item);
  public GatewayListFluent.ItemsNested<A> setNewItemLike(Integer index,Gateway item);
  public GatewayListFluent.ItemsNested<A> editItem(Integer index);
  public GatewayListFluent.ItemsNested<A> editFirstItem();
  public GatewayListFluent.ItemsNested<A> editLastItem();
  public GatewayListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,GatewayFluent<GatewayListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayListFluent<A extends GatewayListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Gateway item);
  public A setToItems(int index,Gateway item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public A addAllToItems(Collection<Gateway> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public A removeAllFromItems(Collection<Gateway> items);
  public A removeMatchingFromItems(Predicate<GatewayBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Gateway> getItems();
  public List<Gateway> buildItems();
  public Gateway buildItem(int index);
  public Gateway buildFirstItem();
  public Gateway buildLastItem();
  public Gateway buildMatchingItem(Predicate<GatewayBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GatewayBuilder> predicate);
  public A withItems(List<Gateway> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.Gateway... items);
  public Boolean hasItems();
  public GatewayListFluent.ItemsNested<A> addNewItem();
  public GatewayListFluent.ItemsNested<A> addNewItemLike(Gateway item);
  public GatewayListFluent.ItemsNested<A> setNewItemLike(int index,Gateway item);
  public GatewayListFluent.ItemsNested<A> editItem(int index);
  public GatewayListFluent.ItemsNested<A> editFirstItem();
  public GatewayListFluent.ItemsNested<A> editLastItem();
  public GatewayListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,GatewayFluent<GatewayListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
